==========
Word Cloud
==========

.. figure:: icons/wordcloud.png

Generates a word cloud from corpus.

Signals
-------

**Inputs**:

-  **Topics**

Selected topics.

-  **Corpus**

Corpus instance.

**Outputs**:

-  **Corpus**

Corpus instance.

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.
